import os 
import time 
import sys 

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    try:
        FILETOWORK="/root/services"
        # Checks if "/root/services" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
            time.sleep(0.5)
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
            time.sleep(0.5)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    time.sleep(0.5)



 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
    try:
        FILETOWORK="/root/ordered.txt"
        # Checks if "/root/ordered.txt" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
            time.sleep(0.5)
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
            time.sleep(0.5)
        
        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                x = x.strip()
            if x and x[0].isdigit():
                print(bcolors.OKGREEN + FILETOWORK + " " + "is numerated" + bcolors.ENDC  )
            else:
                print(bcolors.OKGREEN + FILETOWORK + " " + "is not numerated" + bcolors.ENDC  )
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    time.sleep(0.5)
    sys.exit(1)

 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 



import os 

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


def filestructure():
    FILETOWORK="/tmp/fruits"
    try:
        # Checks if /tmp/fruits is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )

    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    try:
        FILETOWORK="/tmp/services"
        # Checks if /tmp/services is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
        elif os.path.isfile(FILETOWORK):
            print(bcolors.OKGREEN + FILETOWORK + " has been created"+ bcolors.ENDC)
        else:
            print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)

    try:
        FILETOWORK="/tmp/top10"
        num_lines = sum(1 for line in open(FILETOWORK))
        # Checks if /tmp/top10 is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
        elif os.path.isfile(FILETOWORK) and num_lines == 10:
            print(bcolors.OKGREEN + FILETOWORK + " has been created and has %d lines" % num_lines + bcolors.ENDC)
        else:
            print(bcolors.FAIL +  FILETOWORK + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)

    try:
        FILETOWORK="/tmp/bottom10"
        num_lines = sum(1 for line in open(FILETOWORK))
        # Checks if /tmp/bottom10 is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
        elif os.path.isfile(FILETOWORK) and num_lines == 10:
            print(bcolors.OKGREEN + FILETOWORK + " has been created and has %d lines" % num_lines + bcolors.ENDC)
        else:
            print(bcolors.FAIL +  FILETOWORK + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)

    try:
        FILETOWORK="/tmp/sorted_fruits"
        # Checks if /tmp/sorted_fruits is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
        elif os.path.isfile(FILETOWORK):
            print(bcolors.OKGREEN + FILETOWORK + " has been created"+ bcolors.ENDC)
        else:
            print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)

    try:
        FILETOWORK="/tmp/counted_services"
        COUNTED_SERVICES="13921"
        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if COUNTED_SERVICES in x:
                    print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
                else:
                    print("Counted line might be incorrect")
        # Checks if /tmp/counted_services is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
        elif os.path.isfile(FILETOWORK):
            print(bcolors.OKGREEN + FILETOWORK + " has been created"+ bcolors.ENDC)
        else:
            print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 


import os 

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    # Checks if /tmp/test is created.
    if os.path.isdir("/tmp/test"):
        print(bcolors.OKGREEN + "test Folder is created in /tmp" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "test Folder isn't created in /tmp properly, please try again" + bcolors.ENDC)

    # Checks if /tmp/services is created.
    if os.path.isfile("/tmp/services"):
        print(bcolors.OKGREEN + "/tmp/services is created properly" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "/tmp/services is not created properly, please try again" + bcolors.ENDC)

    # Checks if /tmp/passwd is created.
    if os.path.isfile("/tmp/passwd"):
        print(bcolors.OKGREEN + "/tmp/passwd is created properly" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "/tmp/passwd is not created properly, please try again" + bcolors.ENDC)

    # Checks if /tmp/.secret is created.
    if os.path.isfile("/tmp/.secret"):
        print(bcolors.OKGREEN + "/tmp/.secret is created properly" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "/tmp/.secret is not created properly, please try again" + bcolors.ENDC)

    # Checks if /tmp/Photos is created.
    if os.path.isdir("/tmp/Photos") and os.path.isdir("/tmp/Photos/Hawaii") and os.path.isdir("/tmp/Photos/Florida"):
        print(bcolors.OKGREEN + "/tmp/Photos is created with a proper content" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "/tmp/Photos is not created with a proper content, please try again" + bcolors.ENDC)
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 







import sys
sys.path.append('../')

from Classes.shared_scripts.modules import *
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def taskchecker():
    filechecker("/tmp/services")
    filechecker("/tmp/passwd")
    filechecker("/tmp/.secret")
    folderchecker("/tmp/Photos")
    folderchecker("/tmp/Photos/Hawaii")
    folderchecker("/tmp/Photos/Florida")
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 





import os 
import time
import sys
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

FILETOWORK="/tmp/userdata"
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    try:
        FILETOWORK="/tmp/userdata"
        # Checks if "/tmp/userdata" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
            
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
        
        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if "312" and "847" and "773" and "ID" and "First" and  "Last" "E-mail" in x:
                    print(bcolors.OKGREEN +  FILETOWORK + " has the necessary content"+ bcolors.ENDC)
                else:
                    print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content"+ bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
    try:
        FILETOWORK="/tmp/phone"
        # Checks if "/tmp/phone" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
        
        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if "312" and "847" and "773" in x:
                    print(bcolors.OKGREEN +  FILETOWORK + " has the necessary content"+ bcolors.ENDC)
                else:
                    print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content"+ bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
    
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
    try:    
        FILETOWORK="/tmp/email"
        # Checks if "/tmp/email" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
        
        with open(FILETOWORK) as file_content:
            contents = file_content.read()
            for x in contents.splitlines():
                if "abc@gmail.com" and "rob@gmail.com" and "ben@gmail.com" in x:
                    print(bcolors.OKGREEN +  FILETOWORK + " has the necessary content"+ bcolors.ENDC)
                else:
                    print(bcolors.FAIL +  FILETOWORK + " does not have the necessary content"+ bcolors.ENDC)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 


import os
import time
import sys
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filechecker(FILENAME):
    if os.path.isfile(FILENAME):
        print(bcolors.OKGREEN + "%s file is created" % FILENAME + bcolors.ENDC)
        time.sleep(0.5)
    else: 
        print(bcolors.FAIL + "%s file is not created, please try again" % FILENAME + bcolors.ENDC)
        time.sleep(0.5)
        sys.exit(1)
        


def folderchecker(FOLDERNAME):
    if os.path.isdir(FOLDERNAME):
        print(bcolors.OKGREEN + "%s is created with a proper content" % FOLDERNAME + bcolors.ENDC)
        time.sleep(0.5)
    else: 
        print(bcolors.FAIL + "%s is not created with a proper content, please try again" %FOLDERNAME + bcolors.ENDC)
        time.sleep(0.5)
        sys.exit(1)



def sizechecker(FILENAME):
    if os.path.getsize(FILENAME) <= 0:
        print(bcolors.FAIL + FILENAME + " seems to be empty" + bcolors.ENDC  )
        time.sleep(0.5)
    else:
        print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
        time.sleep(0.5)
        sys.exit(1)
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 





import os 
import sys
import time
class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    FILETOWORK="/mnt/secure"
    if os.path.isfile(FILETOWORK):
        print(bcolors.OKGREEN + "secure file is copied in /mnt" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL + "secure file isn't copied in /mnt properly, please try again" + bcolors.ENDC)
        sys.exit(1)
    time.sleep(0.5)
    if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " seems to be empty" + bcolors.ENDC  )
    elif os.path.isfile(FILETOWORK):
        print(bcolors.OKGREEN + FILETOWORK + " has been created"+ bcolors.ENDC)
    else:
        print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
        sys.exit(1)
    time.sleep(0.5)
    FILETOWORK="/etc/yum.repos.d/Media.repo.gz"
    # Checks if /etc/yum.repos.d/Media.repo.gz is created.
    if os.path.isfile(FILETOWORK):
        print(bcolors.OKGREEN + FILETOWORK +  "is created properly" + bcolors.ENDC)
    else: 
        print(bcolors.FAIL +  FILETOWORK + " is not created properly, please try again" + bcolors.ENDC)
        sys.exit(1)
    time.sleep(0.5)



import os 
import sys

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
def filestructure():
    try:
        FILETOWORK="/tmp/configurations"
        # Checks if "/tmp/configurations" is created
        if os.path.getsize(FILETOWORK) <= 0:
            print(bcolors.FAIL + FILETOWORK + " " + "seems to be empty" + bcolors.ENDC  )
        else:
            print(bcolors.OKGREEN + FILETOWORK + " " + "is created" + bcolors.ENDC  )
        try:
            configurations_content = os.listdir(FILETOWORK)
            searchstring = "resolv.conf"
            for x in (x for x in configurations_content if x in searchstring):
                print(bcolors.OKGREEN + FILETOWORK + " " + "has a proper content" + bcolors.ENDC  )
        except FileNotFoundError:
            print("message")
            sys.exit(1)
    except FileNotFoundError:
        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
        sys.exit(1)
filestructure()